@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '1.07';
+$VERSION = '1.08';
 
 #----------------------------------------------------------------------------
 # Library Modules
@@ -604,8 +604,8 @@ sub retrieve_reports {
 
 sub already_saved {
     my ($self,$guid) = @_;
-    my @rows = $self->{METABASE}->get_query('array','SELECT id FROM metabase WHERE guid=?',$guid);
-    return 1	if(@rows);
+    my @rows = $self->{METABASE}->get_query('array','SELECT updated FROM metabase WHERE guid=?',$guid);
+    return $rows[0]->[0]	if(@rows);
     return 0;
 }
 
@@ -1023,51 +1023,46 @@ sub _consume_reports {
         # sync, we have to look at previous entries to ensure we are starting
         # from the right point
         my ($update,$prev,$last) = ($start,$start,$start);
-        my @times = ($start);
+        my @times = ();
 
-        while($update le $end && $prev le $end) {
-            # get list of guids from given start date
-            my $guids = $self->get_next_guids($start);
+        while($update le $end) {
 
-            if($guids) {
-                @guids = grep { !$guids{$_} } @$guids;
-                for my $guid (@guids) {
-                    $self->_log("GUID [$guid]");
+            # get list of guids from last update date
+            my $guids = $self->get_next_guids($update);
+            last    unless($guids);
 
-                    $self->{processed}++;
+            @guids = grep { !$guids{$_} } @$guids;
+            for my $guid (@guids) {
+                # don't process too far
+                shift @times    if(@times > 9);                     # one off
+                push @times, _date_diff($end,$update) <= 0 ? 0 : 1; # one on ... max 10
 
-                    if($self->already_saved($guid)) {
-                        $self->_log(".. already saved\n");
-                        next;
-                    }
+                my $times = 0;
+                $times += $_    for(@times);
+                last    if($times == 10);                           # stop if all greater than end
 
-                    if(my $report = $self->get_fact($guid)) {
-                        $update = $report->{metadata}{core}{update_time};
-                        $self->{report}{guid}   = $guid;
-                        next    if($self->parse_report(report => $report)); # true if invalid report
+                # okay process
+                $self->_log("GUID [$guid]");
 
-                        if($self->store_report()) { $self->_log(".. stored"); $self->{stored}++;    }
-                        else                      { $self->_log(".. already stored");       }
-                        if($self->cache_report()) { $self->_log(".. cached\n"); $self->{cached}++;  }
-                        else                      { $self->_log(".. bad cache data\n");     }
-                    } else {
-                        $self->_log(".. FAIL\n");
-                    }
+                $self->{processed}++;
 
-                    shift @times    if(@times > 4); # one off
-                    push @times, $update;           # one on ... max 5
+                if(my $time = $self->already_saved($guid)) {
+                    $self->_log(".. already saved\n");
+                    $update = $time;
+                    next;
+                }
 
-                    my $times = 0;
-                    for my $time (@times) {
-                        next    if(_date_diff($end,$time) <= 0);
-                        $times++;
-                    }
+                if(my $report = $self->get_fact($guid)) {
+                    $update = $report->{metadata}{core}{update_time};
+                    $self->{report}{guid}   = $guid;
+                    next    if($self->parse_report(report => $report)); # true if invalid report
 
-                    last    if($times == @times);   # stop if all past endh
-
-#                    last    if($update gt $end && $last gt $end);
-#                    $prev = $last;
-#                    $last = $update;
+                    if($self->store_report()) { $self->_log(".. stored"); $self->{stored}++;    }
+                    else                      { $self->_log(".. already stored");       }
+                    if($self->cache_report()) { $self->_log(".. cached\n"); $self->{cached}++;  }
+                    else                      { $self->_log(".. bad cache data\n");     }
+                } else {
+                    $self->_log(".. FAIL\n");
                 }
             }
 
